@@ -113,6 +113,10 @@ def extra_check(file, detections):
     help_lines = []
     duplicate_check = 0
     for line in file.split('\n'):
+        # Ignore annotations.
+        if line.strip().startswith('['):
+            continue
+
         # Some symbols should not have a space in front.
         for match in re.finditer(r'\s,\s?', line):
             detections.append((lineNumber, match.span()[0], match.span()[1],
@@ -156,7 +160,8 @@ def extra_check(file, detections):
 
         # Correct use of indentation
         if not(line.startswith('\t') or line.startswith('    ')):
-            keywords = ["vocabulary", "structure", "theory", "procedure", "}"]
+            keywords = ["vocabulary", "structure", "theory", "procedure", "}",
+                        "display"]
             if not(len(line.strip()) == 0
                    or any(word in line for word in keywords)):
                 detections.append((lineNumber, 0, 4,
@@ -173,16 +178,19 @@ def extra_check(file, detections):
         else:
             if (any(symbol in line for symbol in unicode_symbols) and
                     any(symbol in line for symbol in ascii_symbols)):
+                print('a')
                 detections.append((lineNumber, 0, 4,
                                    "Style: don't mix unicode and ASCII",
                                    "Warning"))
             elif (any(symbol in line for symbol in unicode_symbols) and
                     consistence == "ASCII"):
+                print('b')
                 detections.append((lineNumber, 0, 4,
                                    "Style: don't mix unicode and ASCII",
                                    "Warning"))
             elif (any(symbol in line for symbol in ascii_symbols) and
                     consistence == "unicode"):
+                print('c')
                 detections.append((lineNumber, 0, 4,
                                    "Style: don't mix unicode and ASCII",
                                    "Warning"))
